<?php
$page_title = "潜在的な重複アカウント";
include_once('template/base_head.php');
?>
			<!-- サイドバー -->
			<aside id="colLeft">
				<h1><a href=""><img src="../img/logo.png" alt="iWallet"></a></h1>
				<div class="aside-heading">
					
				</div>
				<form id="searchForm" action="" method="post">
					<table class="conditions fontS w100p">
						<colgroup>
							<col class="w40p">
							<col class="w60p">
						</colgroup>
						<tr>
							<td style="font-weight:bold">メールアドレス:&nbsp;</th>
							<td><?php $this -> echoMail(); ?></td>
						</tr>
						<tr>
							<th style="font-weight:bold">口座番号:&nbsp;</th>
							<td><?php $this -> echoAccountNumber(); ?></td>
						</tr>
						<tr>
							<td style="font-weight:bold">氏名:&nbsp;</th>
							<td><?php $this -> echoName(); ?></td>
						</tr>
						<tr>
							<th style="font-weight:bold">生年月日:&nbsp;</th>
							<td><?php $this -> echoBirth(); ?></td>
						</tr>
						<tr>
							<td style="font-weight:bold">ステータス:&nbsp;</th>
							<td><?php $this -> echoAccountStatus(); ?></td>
						</tr>
						<tr>
							<th style="font-weight:bold">住所:&nbsp;</th>
							<td><?php $this -> echoAddress(); ?></td>
						</tr>
						<tr>
							<th style="font-weight:bold">開設日</th>
							<td><?php $this -> echoCreateTime(); ?></td>
						</tr>
						<tr>
							<th  style="font-weight:bold">IPアドレス</th>
							<td><?php $this -> echoIPAddress(); ?></td>
						</tr>
						<tr>
							<th  style="font-weight:bold">国名</th>
							<td><?php $this -> echoCountry(); ?></td>
						</tr>
						<tr>
							<th style="font-weight:bold">引き合い:&nbsp;</th>
							<td><?php $this -> echoCount(); ?></td>
						</tr>
										
					</table>
					<input type="hidden" value="検索" id="type_search" name="type" />
				</form>
			</aside>
			<!-- /サイドバー -->
			<!-- メインカラム -->
			<div id="colMain">
				<div class="mainIn">
<?php include_once('template/base_nav.php'); ?>
					<article>
						<div class="article-heading">
							<h2><?php echo $page_title; ?></h2>
							<!-- <?php $this -> dispPager(); ?> -->
						</div>
						<?php // $this -> echoMessage(); ?>
						<form id="acForm" action="" method="post">
							<table class="table col bdr default odd w100p fontXS calign">
								<tr>
									<th class="w10p">メールアドレス</th>
									<th class="w5p">口座番号</th>
									<th class="w5p">氏名</th>
									<th class="w5p">生年月日</th>
									<th class="w5p">ステータス</th>
									<!-- <th class="w5p">Country</th> -->
									<th class="w10p">住所</th>
									<th class="w10p">IPアドレス</th>
									<th class="w10p">国名</th>
									<th class="w10p">理由</th>
									<!-- <th class="w5p">開設日</th> -->
									<!-- <th class="w5p">Date of Account Closing</th> -->
									<th class="w3p">しきい値</th>
									<th class="w3p">削除</th>
								</tr>
								<?php /* $this -> echoList(); */ ?>
								<?php $this -> echoJson() ?>
							</table>
							<!-- <div style="display: flex; justify-content: flex-end; margin-bottom:-25px">
							<p>Account Number:  <input type="text"> <input type="button" id="btnAdd" value="Add" class="btn bg-default px50 hi22"> </p>
							</div> -->
							<input type="hidden" value="account_edit" id="action" name="action" />
							<input type="hidden" value="" id="type" name="type" />
							<input type="hidden" id="detail_account" name="detail_account" />
							<input type="hidden" id="user_account" name="user_account" value="<?php $this -> echoAccountNumber(); ?>" />
							<input type="hidden" id="child_account" name="child_account" />
						</form>
						<div class="article-bottom">
							<!-- <?php  $this -> dispPager(); ?> -->
						</div>
					</article>
				</div>
			</div>
			<!-- /メインカラム -->
		</div>
<?php include_once('template/base_foot.php'); ?>
	</div>
	<script src="../js/account_list.js"></script>
</body>
</html>
